 /*
	$Id: Directory.h 1234 2018-12-02 13:26:01Z john $

	This file is part of the 4c LDAP library.

	The 4c LDAP library is Copyright (c) 2018, The 4c Company.

	The 4c LDAP library is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The 4c LDAP library is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __ldap4c_Directory_h__
#define __ldap4c_Directory_h__

#include <ldap4c/ldap4c.h>

#include <ldap4c/country.h>
#include <ldap4c/inetOrgPerson.h>
#include <ldap4c/groupOfNames.h>

#include <ldap.h>

namespace Ldap4c
{
	class LDAP4c_Export Directory
	{
		private:
			static Base::Dn _dnBase;
			static Base::Dn _dnContact;
			static countryMap _countryS;
			static countryPtrMap _pcountryS;
			static inetOrgPersonMap _inetOrgPersonS;
			static groupOfNamesMap _groupOfNamesS;
			static LDAP* _pldap;

		public:
			static void initialize( const std::string& strLDAP, const Base::Dn& dnBase, const Base::Dn& dnBind = Base::Dn(), const std::string& strPassword = std::string() );

			static void setContactBaseDn( const Base::Dn& dnContact );
			static const Base::Dn& contactBaseDn();

			static LDAP* ldap();

			static const countryMap& countrys();
			static const countryPtrMap& countrysByCode();
			static const inetOrgPersonMap& inetOrgPersons();
			static const groupOfNamesMap& groupOfNames();

			static void createInetOrgPerson( LDAP* pld, const inetOrgPerson& person, const Base::Dn& dnGroup = Base::Dn() );
			static void updateInetOrgPerson( LDAP* pld, const inetOrgPerson& person, const Base::Dn& dnGroup = Base::Dn() );

		protected:
			static void bind( const Base::Dn& dn, const std::string& strPassword );
			static void loadCountrys( LDAP* pld );
			static void loadInetOrgPersons( LDAP* pld );
			static void loadGroupOfNames( LDAP* pld );

	};
}

#endif /* !__ldap4c_Directory_h__ */
