/*
	$Id: country.h 1233 2018-12-02 13:06:35Z john $

	This file is part of the 4c LDAP library.

	The 4c LDAP library is Copyright (c) 2018, The 4c Company.

	The 4c LDAP library is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The 4c LDAP library is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __ldap4c_country_h__
#define __ldap4c_country_h__

#include <ldap4c/ldap4cbase.h>

#include <string>
#include <map>

#include <ldap.h>

namespace Ldap4c
{
	class LDAP4c_Export country : public Base
	{
		private:
			std::string _strC;
			std::string _strDescription;

		public:
			country();
			country( const Base::Dn& dn );
			country( const country& ctry );
			virtual ~country();

			country& operator=( const country& ctry );

			const std::string& c() const;
			const std::string& description() const;

			void setDescription( const std::string& strDescription );

			virtual const std::string& objectClass() const;

			static country fromMessage( LDAP* pld, LDAPMessage* psubresult );
			static country search( LDAP* pld, const Base::Dn& dn );
	};

	class LDAP4c_Export countryMap : public std::map<Base::Dn, country>
	{
		public:
			static countryMap load( LDAP* pld, const Base::Dn& dnBase );
	};

	class LDAP4c_Export countryPtrMap : public std::map<std::string, country*>
	{
	};
}

#endif /* !__ldap4c_country_h__ */
