/*
	$Id: groupOfNames.h 1233 2018-12-02 13:06:35Z john $

	This file is part of the 4c LDAP library.

	The 4c LDAP library is Copyright (c) 2018, The 4c Company.

	The 4c LDAP library is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The 4c LDAP library is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __ldap4c_groupOfNames_h__
#define __ldap4c_groupOfNames_h__

#include <ldap4c/ldap4cbase.h>

#include <ldap4c/inetOrgPerson.h>

#include <string>
#include <map>

#include <ldap.h>

namespace Ldap4c
{
	class LDAP4c_Export groupOfNames : public Base
	{
		private:
			std::string _strCn;
			std::string _strDescription;
			std::string _strBusinessCategory;
			inetOrgPersonPtrMap _memberS;

		public:
			groupOfNames();
			groupOfNames( const Base::Dn& dn );
			groupOfNames( const groupOfNames& group );
			virtual ~groupOfNames();

			groupOfNames& operator=( const groupOfNames& group );

			const std::string& cn() const;
			const std::string& description() const;
			const std::string businessCategory() const;
			const inetOrgPersonPtrMap& member() const;

			void setDescription( const std::string& strDescription );
			void setBusinessCategory( const std::string& strBusinessCategory );
			void setMember( const inetOrgPerson& member );

			virtual const std::string& objectClass() const;

			static groupOfNames fromMessage( LDAP* pld, LDAPMessage* psubresult );
			static groupOfNames search( LDAP* pld, const Base::Dn& dn );
	};

	class LDAP4c_Export groupOfNamesMap : public std::map<Base::Dn, groupOfNames>
	{
		public:
			static groupOfNamesMap load( LDAP* pld, const Base::Dn& dnBase );
	};
}

#endif /* !__ldap4c_groupOfNames_h__ */
