/*
	$Id: inetOrgPerson.h 1233 2018-12-02 13:06:35Z john $

	This file is part of the 4c LDAP library.

	The 4c LDAP library is Copyright (c) 2018, The 4c Company.

	The 4c LDAP library is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The 4c LDAP library is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __ldap4c_inetOrgPerson_h__
#define __ldap4c_inetOrgPerson_h__

#include <ldap4c/ldap4cbase.h>

#include <string>
#include <map>
#include <set>

#include <ldap.h>

namespace Ldap4c
{
	class country;
	
	class LDAP4c_Export inetOrgPerson : public Base
	{
		private:
			std::string _strCn;
			std::string _strSn;
			std::string _strUid;
			std::string _strDestinationIndicator;
			std::string _strDisplayName;
			std::string _strGivenName;
			std::string _strHomePhone;
			std::string _strHomePostalAddress;
			std::string _strInitials;
			std::string _strL;
			std::set<std::string> _strMailS;
			std::string _strMobile;
			std::string _strO;
			std::string _strPostalCode;
			std::string _strSt;
			std::string _strStreet;
			std::string _strTelephoneNumber;
			std::string _strTitle;
			std::string _strIdentifier;
			const country* _pcountry;

		public:
			inetOrgPerson();
			inetOrgPerson( const Base::Dn& dn );
			inetOrgPerson( const inetOrgPerson& pers );
			virtual ~inetOrgPerson();

			inetOrgPerson& operator=( const inetOrgPerson& pers );

			const std::string& cn() const;
			const std::string& sn() const;
			const std::string& uid() const;
			const std::string& destinationIndicator() const;
			const std::string& displayName() const;
			const std::string& givenName() const;
			const std::string& homePhone() const;
			const std::string& homePostalAddress() const;
			const std::string& initials() const;
			const std::string& l() const;
			const std::set<std::string>& mail() const;
			const std::string& mobile() const;
			const std::string& o() const;
			const std::string& postalCode() const;
			const std::string& st() const;
			const std::string& street() const;
			const std::string& telephoneNumber() const;
			const std::string& title() const;
			const Ldap4c::country& ctry() const;

			void setCn( const std::string& strCn );
			void setSn( const std::string& strSn );
			void setUid( const std::string& strUid );
			void setDestinationIndicator( const std::string& strDestinationIndicator );
			void setDisplayName( const std::string& strDisplayName );
			void setGivenName( const std::string& strGivenName );
			void setHomePhone( const std::string& strHomePhone );
			void setHomePostalAddress( const std::string& strHomePostalAddress );
			void setInitials( const std::string& strInitials );
			void setL( const std::string& strL );
			void setMail( const std::string& strMail );
			void setMobile( const std::string& strMobile );
			void setO( const std::string& strO );
			void setPostalCode( const std::string& strPostalCode );
			void setSt( const std::string& strSt );
			void setStreet( const std::string& strStreet );
			void setTelephoneNumber( const std::string& strTelephoneNumber );
			void setTitle( const std::string& strTitle );
			void setCtry( const Ldap4c::country& ctry );

			virtual const std::string& objectClass() const;

			static inetOrgPerson fromMessage( LDAP* pld, LDAPMessage* psubresult );
			static inetOrgPerson search( LDAP* pld, const Base::Dn& dn );
			static inetOrgPerson create( LDAP* pld, const inetOrgPerson& source );
			void update( LDAP* pld );

		protected:
			static inetOrgPerson write( LDAP* pld, const inetOrgPerson& source, Base::Operation op );
	};

	class LDAP4c_Export inetOrgPersonMap : public std::map<Base::Dn, inetOrgPerson>
	{
		public:
			static inetOrgPersonMap load( LDAP* pld, const Base::Dn& dnBase );
	};

	class LDAP4c_Export inetOrgPersonPtrMap : public std::map<Base::Dn, const inetOrgPerson*>
	{
	};
}

#endif /* !__ldap4c_inetOrgPerson_h__ */
