/*
	$Id: ldap4cbase.h 1231 2018-12-01 19:46:23Z john $

	This file is part of the 4c LDAP library.

	The 4c LDAP library is Copyright (c) 2018, The 4c Company.

	The 4c LDAP library is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The 4c LDAP library is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __ldap4c_ldap4cbase_h__
#define __ldap4c_ldap4cbase_h__

#include <ldap4c/ldap4c.h>

#include <string>

namespace Ldap4c
{
	class LDAP4c_Export Base
	{
		public:
			class LDAP4c_Export Dn
			{
				private:
					std::string _strDn;
					std::string _strBranch;
					std::string _strLeaf;
					std::string _strIdentifier;
					std::string _strId;

				public:
					Dn();
					Dn( const std::string& strDn );
					Dn( const Dn& dn );
					virtual ~Dn();

					Dn& operator=( const Dn& dn );

					bool operator==( const Dn& dn ) const;
					bool operator!=( const Dn& dn ) const;
					bool operator<( const Dn& dn ) const;

					const std::string& dn() const;
					const std::string& branch() const;
					const std::string& leaf() const;
					const std::string& identifier() const;
					const std::string& id() const;
			};

			enum Operation{ opCreate, opUpdate };

		private:
			Dn _dn;

		public:
			Base();
			Base( const Dn& dn );
			Base( const Base& base );
			virtual ~Base();

			Base& operator=( const Base& base );

			const Dn& dn() const;
			
			virtual const std::string& objectClass() const = 0;
	};
}

#endif /* !__ldap4c_ldap4cbase_h__ */
